import React, {useContext, useEffect, useState} from "react";
import { RobinChatContext } from "../../context/RobinChatContext";
import SvgMoreHorizontal from "../../icons/MoreHorizontal";
import { Conversation } from "../../models/Conversation";
import { getConversationName } from "../../utils/functions";
import { ChatAvatar } from "../ChatAvatar/ChatAvatar";
import {ConversationMenu} from "../ConversationMenu/ConversationMenu";
import {State} from "../../context/state";

interface Props {
  chat: Conversation | undefined
}

export const ActiveConversationHeader: React.FC<Props> = ({ chat }) => {
  const [menuVisible, setMenuVisible] = useState<boolean>()
  const {state, setState} = useContext(RobinChatContext)

  useEffect(() => {
    if (!state?.dialogActive) setMenuVisible(false)
  }, [state?.dialogActive])

  useEffect(() => {
    const stateCopy: State = {...state}
    stateCopy.dialogActive = menuVisible
    if (setState) setState(stateCopy)
  }, [menuVisible])

  return (
    <div className="robin__active_conversation_header">
      <div className="conversation__profile_info icon__text">
        <ChatAvatar conversation={chat} />
        <div className="online__indicator zoom-in-anim" />
        <div className="texts">
          <div className="profile__name">
            {getConversationName(chat, state)}
          </div>
          <div className="profile__status">
            Online
          </div>
        </div>
      </div>
      <button className="icon__btn" onClick={() => setMenuVisible(true)}>
        <SvgMoreHorizontal />
      </button>

      {/* MORE MESSAGE OPTIONS */}
      <ConversationMenu
        setMenuVisible={setMenuVisible}
        animClass={menuVisible ? 'open-menu-anim' : 'close-menu-anim'}/>

      {/* REACTIONS */}
      <div className="msg__reactions">
        <button className="icon__btn">
          ⁉️
        </button>
        <button className="icon__btn">
          😂
        </button>
        <button className="icon__btn">
          ❤️
        </button>
        <button className="icon__btn">
          👍
        </button>
        <button className="icon__btn">
          👎
        </button>
      </div>
    </div>
  )
}
