import React, {useContext, useEffect, useState} from "react"
import {Message} from "../../utils/messages-data"
import { UnreadMsgsHeader } from "../UnreadMsgsHeader/UnreadMsgsHeader"
import {RobinChatContext} from "../../context/RobinChatContext";
import BarLoader from "react-spinners/BarLoader";
import {MessagesListByDate} from "../MessagesListByDate/MessagesListByDate";
import {Conversation} from "../../models/Conversation";

interface Props {
  chat: Conversation | undefined,
}

const scrollMessagesToBottom = () => {
  const activeMessages = document.querySelector(".robin__active_conversation_msgs")
  activeMessages?.scroll(0, activeMessages?.scrollHeight)
}

export const ActiveConversationMessages: React.FC<Props> = ({ chat }) => {
  const unreadMessages = (Object.values(chat?.unread_messages || { 0: 0 }) as Array<any>)[0].unread_count
  const [allMessages, setAllMessages] = useState<Array<Message>>([chat?.last_message])
  const [messages, setMessages] = useState<Array<any>>([chat?.last_message])
  const [conversationsLoading, setConversationsLoading] = useState<boolean>(false)
  const {state} = useContext(RobinChatContext)
  const robin = state?.robin

  useEffect(() => {
    setMessages([chat?.last_message])
    if (state?.userToken && chat) {
      setConversationsLoading(true)
      robin?.getConversationMessages(chat._id, state.userToken).then((messages) => {
        setAllMessages(messages.data)
        const messagesMap = sortMessages(messages.data || [])
        setMessages(Array.from(messagesMap))
        setConversationsLoading(false)

        scrollMessagesToBottom()
      })
    }
  }, [chat])

  return (
    <div className="robin__active_conversation_msgs">
      <BarLoader width="100%" color="#15AE73" cssOverride={{ position: "absolute", inset: 0 }} loading={conversationsLoading} />
      {messages.map((msg, index) => <MessagesListByDate allMessages={allMessages} key={`message-list-by-date-${index}`} date={msg ? msg[0] : ''} messages={msg ? msg[1] : ''} isGroup={chat?.is_group} />)}
      {unreadMessages > 0 && <UnreadMsgsHeader msgs={unreadMessages}/>}
    </div>
  )
}

export const sortMessages = (messages: Array<Message>) => {
  const messagesDays = new Set<string>()
  const messagesMap = new Map()

  for (const message of messages) {
    const dayMessageSent = message.created_at?.slice(0, 10)
    if(dayMessageSent) messagesDays.add(dayMessageSent)
  }
  for (const day of Array.from<string>(messagesDays)) {
     const messagesFromADay = []
    for (const message of messages) {
      if (message?.created_at?.includes(day)) {
        messagesFromADay.push(message)
      }
    }
    messagesMap.set(day, messagesFromADay)
  }
  return messagesMap
}
