import React, { useContext, useEffect, useState } from "react";
import SvgEmoji from "../../icons/Emoji";
import SvgMicrophone from "../../icons/Microphone";
import SvgPlus from "../../icons/Plus";
import {Conversation} from "../../models/Conversation";
import { Picker } from 'emoji-mart'
import 'emoji-mart/css/emoji-mart.css'
import SvgSend from "../../icons/Send";
import { RobinChatContext } from "../../context/RobinChatContext";
import { CHANNEL } from "../../utils/constants";
import { State } from "../../context/state";
import { SendMediaMenu } from "../SendMediaMenu/SendMediaMenu";

interface Props {
  chat: Conversation | undefined
}

export const ActiveMessageInput: React.FC<Props> = ({ chat }) => {
  const [emojiVisible, setEmojiVisible] = useState(false)
  const [message, setMessage] = useState('')
  const {state, setState} = useContext(RobinChatContext)
  const [menuVisible, setMenuVisible] = useState<boolean>(false)
  const robin = state?.robin

  useEffect(() => {
    if (!state?.dialogActive) setMenuVisible(false)
  }, [state?.dialogActive])

  useEffect(() => {
    const stateCopy: State = {...state}
    stateCopy.dialogActive = menuVisible
    if (setState) setState(stateCopy)
  }, [menuVisible])

  const addEmoji = (emoji: string) => setMessage(message + emoji)

  /**
   * @param event if event is 'click', the click of [.icon_btn] button sends a message ,
   * if not, then keyboard event enter sends a message.
   */
  const sendMessage = (event: any) => {
    if (event.key === 'Enter' || event === 'click') {
      const messageObj = {
        msg: message,
        receiver_token: state?.userToken === chat?.receiver_token ? chat?.sender_token : chat?.receiver_token,
        sender_token: state?.userToken,
        timestamp: new Date()
      }
      if (chat && state && state.conn) {
        robin?.sendMessageToConversation(
          messageObj,
          state.conn,
          CHANNEL,
          chat._id,
          state.userToken
        )
      } else {
        throw Error('Error with Conversation | State | Connection Issue')
      }
      setMessage('')
    }
  }

  return (
    <div className="robin__active_msg_input">
      <div className={`emoji_picker ${emojiVisible ? 'revealed' : ''}`}>
        <Picker onSelect={(e) => addEmoji(e.native)} />
      </div>

      {/* MENU BUTTON */}
      <button className={`icon__btn add__icon ${menuVisible ? 'rotate_btn' : ''}`} onClick={() => setMenuVisible(true)}>
        <SvgPlus />
      </button>

      {/* MENU */}
      <SendMediaMenu
        setMenuVisible={setMenuVisible}
        animClass={menuVisible ? 'revealed' : ''}
      />

      <div className="form__input">
        <textarea placeholder="Type your message..." value={message} onKeyDown={(e) => sendMessage(e)} onChange={(e) => setMessage(e.target.value)} />
        <div className="emoji__area">
          <button className="form__icon icon__btn" onClick={() => {setEmojiVisible(!emojiVisible)}}>
            <SvgEmoji />
          </button>
        </div>
      </div>
      {!message && <button className="icon__btn mic__icon zoom-in-anim">
        <SvgMicrophone />
      </button>}
      {message && <button className="icon__btn mic__icon zoom-in-anim" onClick={() => sendMessage('click')}>
        <SvgSend />
      </button>}
    </div>
  )
}
