import React, {useEffect, useState} from "react"
import {Message} from "../../utils/messages-data";
import {getFilename, getFileType} from "../../utils/functions";
import {AUDIO_FILE_TYPES, FILE_TYPES} from "../../utils/constants";
import {Pause, Play} from "../../icons";
import {PuffLoader} from "react-spinners";

interface Props {
  message: Message
}

export const AudioMsg: React.FC<Props> = ({ message }) => {
  const filename = message?.content?.attachment ? getFilename(message?.content?.attachment) : ''
  const fileType = FILE_TYPES.includes(getFileType(filename)) ? getFileType(filename) : 'DOC'
  let audioPlayer: HTMLAudioElement | null = document.getElementById(`robin__audio_${message?._id}`) as HTMLMediaElement

  const [audioDuration, setAudioDuration] = useState(0)
  const [audioPlaying, setAudioPlaying] = useState(false)
  const [audioLoading, setAudioLoading] = useState(false)
  const [audioProgress, setAudioProgress] = useState(0)

  useEffect(() => {
    audioPlayer = document.getElementById(`robin__audio_${message?._id}`) as HTMLMediaElement

    // Listen for when audio is loaded
    setAudioLoading(true)
    audioPlayer?.addEventListener('loadeddata', () => {
      setAudioLoading(false)
      if (audioPlayer?.duration) setAudioDuration(audioPlayer?.duration)
    })

    // Listen to play/pause of Audio
    audioPlayer?.addEventListener('playing', () => {
      setAudioPlaying(true)
      if (audioPlayer?.duration) setAudioDuration(audioPlayer?.duration)
    })

    // Listen to pause of Audio
    audioPlayer?.addEventListener('pause', () => {
      setAudioPlaying(false)
    })

    // Listen to end of Audio
    audioPlayer?.addEventListener('ended', () => {
      setAudioProgress(0)
    })

    // Listen to audio progress in duration
    audioPlayer?.addEventListener('timeupdate', () => {
      if (audioPlayer) {
        setAudioDuration(audioPlayer?.currentTime)
        setAudioProgress((audioPlayer.currentTime / audioPlayer.duration * 100))
      }
    })
  }, [])

  const togglePlayPause = () => audioPlayer?.paused ? audioPlayer?.play() : audioPlayer?.pause()

  const seekLineClicked = (ev: React.MouseEvent<HTMLDivElement>) => {
    let seekTime = 0
    // @ts-ignore
    const offsetLeft = ev.target.getBoundingClientRect().left
    const clickOffset = ev.clientX - offsetLeft
    if (audioPlayer) {
      seekTime = (clickOffset / 150) * audioPlayer?.duration
      audioPlayer.currentTime = seekTime
      setAudioDuration(seekTime)
      audioPlayer?.play()
    }
  }

  return ((message.content?.is_attachment && AUDIO_FILE_TYPES.includes(fileType)) ?
    <div className="messages__audio_ctn">
      {/* HIDDEN AUDIO PLAYER TO BE INTERFACED */}
      <audio controls id={`robin__audio_${message?._id}`}>
        <source src={message?.content.attachment} type="audio/mpeg" />
      </audio>

      {/* CUSTOM AUDIO PLAYER */}
      <div className="audio_player">
        <div className="play_control">
          <button className="icon__btn" onClick={() => {togglePlayPause()}}>
            <PuffLoader color="#15AE73" size={24} loading={audioLoading}/>
            {!audioPlaying && !audioLoading && <Play className={`zoom-in-anim`}/>}
            {audioPlaying && !audioLoading && <Pause className={`zoom-in-anim`}/>}
          </button>
        </div>
        <div className="audio_seek">
          <div className="audio__seek_line active" style={{ width: `${audioProgress}%` }} onClick={(event) => {seekLineClicked(event)}} />
          <div className="audio__seek_circle" style={{ left: `${audioProgress}%` }} />
          <div className="audio__seek_line" onClick={(event) => {seekLineClicked(event)}} />
        </div>
        <div className="audio_timestamp">
          {new Date(audioDuration * 1000).toISOString().substr(14, 5)}
        </div>
      </div>
    </div>
      : <React.Fragment />
  )
}
