import React, { useContext, useEffect, useState } from "react";
import { RobinChatContext } from "../../context/RobinChatContext";
import { State } from "../../context/state";
import { MoreHorizontal } from "../../icons";
import { Conversation } from "../../models/Conversation";
import { getConversationLastUpdated, getConversationName } from "../../utils/functions";
import { ChatAvatar } from "../ChatAvatar/ChatAvatar";
import { ConversationMenu } from "../ConversationMenu/ConversationMenu";

export interface Props {
  key: String,
  conversation: Conversation
}

export const ConversationCard: React.FC<Props> = ({ conversation }) => {
  const [menuVisible, setMenuVisible] = useState<boolean>(false)
  const [time, setTime] = useState<string>('')
  const {state, setState} = useContext(RobinChatContext)
  const unreadMessages = (Object.values(conversation?.unread_messages || { 0: 0 }) as Array<any>)[0].unread_count

  const updateActiveChat = (activeChat: Conversation) => {
    const stateCopy: State = {...state}
    stateCopy.activeChat = activeChat
    setState ? setState(stateCopy) : null
  }

  useEffect (() => {
    setTime(getConversationLastUpdated(conversation, state))
    setInterval(() => {
      setTime(getConversationLastUpdated(conversation, state))
    }, 10000)
  })

  useEffect(() => {
    if (!state?.dialogActive) setMenuVisible(false)
  }, [state?.dialogActive])

  useEffect(() => {
    const stateCopy: State = {...state}
    stateCopy.dialogActive = menuVisible
    if (setState) setState(stateCopy)
  }, [menuVisible])

  return (
    <div className={`robin__chat_card__ctn`} onClick={() => !menuVisible ? updateActiveChat(conversation) : null}>
      {/* CHAT CARD MAIN CONTENT */}
      {conversation && <div className={`robin__chat_card ${state?.activeChat === conversation ? 'active' : ''}`}>
        <div className="chat__user_msg icon__text">
          <ChatAvatar conversation={conversation}/>
          <div className="user__name_msg text">
            <div className="name">
              {getConversationName(conversation, state)}
            </div>
            <div className="latest__msg">
              {conversation?.last_message?.msg}
            </div>
          </div>
        </div>
        <div className="chat__timeline">
          {/* TIME REFRESHES EVERY 10S */}
          <div className="chat__time">
            {time}
          </div>
          <div className={`chat__unread zoom-in-anim ${unreadMessages > 0 ? 'visible' : 'invisible'}`}>
            {unreadMessages}
          </div>
        </div>
      </div>}

      {/* MENU BUTTON */}
      <button className="chat__more_btn icon__btn" onClick={(e) => {setMenuVisible(true); e.stopPropagation()}}>
        <MoreHorizontal />
      </button>

      {/* MENU */}
      <ConversationMenu
        setMenuVisible={setMenuVisible}
        animClass={menuVisible ? 'revealed' : ''}
      />
    </div>
  )
}
