import React, { Dispatch, SetStateAction, useContext } from "react";
import { RobinChatContext } from "../../context/RobinChatContext";
import SvgMultiply from "../../icons/Multiply";
import SvgNewGroup from "../../icons/NewGroup";
import SvgSearch from "../../icons/Search";
import { ALPHABETS, ASCII_SMALL_ALPHABETS_RANGE, SIDEBAR_STATE_ACTIVE, SIDEBAR_STATE_NEW_CHAT, SIDEBAR_STATE_NEW_GROUP } from "../../utils/constants";
import { User } from "../../utils/users-data";
import { UsersByInitial } from "../UsersByInitial/UsersByInitial";


interface Props {
  sidebarPartVisible: string,
  setSidebarPartVisible: Dispatch<SetStateAction<string>>
}

/**
 * Method to return all users that match the [letter] initial
 * @param letter initial that determines users
 * @returns an array of users, Array<User>
 */
  export const usersByInitial = (users: Array<User>, letter: string) : Array<User> | undefined => {
  if (letter === '#') {
    return users?.filter(user => {
      const initialASCII = user.fullname.trim().toLowerCase().charCodeAt(0)        
      return !(initialASCII >= ASCII_SMALL_ALPHABETS_RANGE[0] && initialASCII <= ASCII_SMALL_ALPHABETS_RANGE[1])
    })
  }
  return users?.filter(user => user.fullname[0].trim().toLowerCase() === letter)
}

export const NewChat: React.FC<Props> = ({ sidebarPartVisible, setSidebarPartVisible }) => {

  const { state } = useContext(RobinChatContext)
  const users = state?.users?.sort((a, b) => a.fullname > b.fullname ? 1 : -1)

  return (
    <div className={`sec__sidebar ${sidebarPartVisible === SIDEBAR_STATE_NEW_CHAT ? 'revealed' : ''}`}>
      <div className="sec__sidebar_header icon__text">
        <button className="icon__btn" onClick={() => setSidebarPartVisible(SIDEBAR_STATE_ACTIVE)}>
          <SvgMultiply />
        </button>
        <div className="text">New Chat</div>
      </div>
      <div className="sidebar__row_2">
        <div className="form__input">
          <input type="text" className='icon__input' placeholder='Search people...' />
          <div className="form__icon">
            <SvgSearch />
          </div>
        </div>
      </div>
      <button className="sidebar__archive_btn icon__btn" onClick={() => setSidebarPartVisible(SIDEBAR_STATE_NEW_GROUP)}>
        <div className="icon__text">
          <SvgNewGroup />
          <span className="text">Create New Group</span>
        </div>
      </button>
      <div className="robin__archived_chats chat__list">
        { ALPHABETS?.map(letter => <UsersByInitial key={`users-by-${letter}`} letter={letter} users={usersByInitial(users, letter)} />) }
      </div>
    </div>
  )
}