import React, { Dispatch, SetStateAction, useState } from "react";
import SvgMultiply from "../../icons/Multiply";
import { CREATE_GROUP_PARTICIPANTS, SIDEBAR_STATE_ACTIVE, SIDEBAR_STATE_NEW_GROUP } from "../../utils/constants";
import { SelectGroupParticipants } from "../SelectGroupParticipants/SelectGroupParticipants";


interface Props {
  sidebarPartVisible: string,
  setSidebarPartVisible: Dispatch<SetStateAction<string>>
}

export const NewGroupChat: React.FC<Props> = ({ sidebarPartVisible, setSidebarPartVisible }) => {
  const [createGroupSection, setCreateGroupSection] = useState('')
  const [groupName, setGroupName] = useState('')
  const [groupImage, setGroupImage] = useState<File | undefined>(undefined)
  const [groupImageUrl, setGroupImageUrl] = useState<string>('')

  const getImage = (file: File | undefined) => {
    if (file) {
      const url = URL.createObjectURL(file)
      setGroupImage(file)
      setGroupImageUrl(url)
    }
  }

  return (
    <div className={`sec__sidebar ${sidebarPartVisible === SIDEBAR_STATE_NEW_GROUP ? 'revealed' : ''}`}>
      <div className="sec__sidebar_header with__done">
        <div className="icon__text">
          <button className="icon__btn" onClick={() => setSidebarPartVisible(SIDEBAR_STATE_ACTIVE)}>
            <SvgMultiply />
          </button>
          <div className="text">New Group Chat</div>
        </div>
        <button className="icon__btn done__btn" disabled={groupName.length === 0} onClick={() => setCreateGroupSection(CREATE_GROUP_PARTICIPANTS)}>
          Next
        </button>
      </div>
      <div className="sidebar__row_2 sidebar__file">
        <div className="form__input">
          <div className="group__initials">
            {`${groupName[0] || ''}${groupName.split(' ')[1] ? groupName.split(' ')[1][0] : ''}`}
          </div>
          <img src={groupImageUrl} alt="Group Image" className={groupImage ? 'revealed' : ''} />
          <label className="file__input">
            <input type="file" onChange={e => getImage(e.target.files ? e.target.files[0] : undefined)}/>
          </label>
        </div>
        <h2>Tap to Add Group Image</h2>
      </div>
      <div className="sidebar__row_2">
        <div className="form__input">
          <div className="form__label">
            Group Name
          </div>
          <input type="text" placeholder='My Group' onChange={(e) => {setGroupName(e.target.value)}}  />
        </div>
      </div>
      <SelectGroupParticipants 
        groupName={groupName}
        groupImage={groupImage}
        createGroupSection={createGroupSection}
        setSidebarPartVisible={setSidebarPartVisible}
        setCreateGroupSection={setCreateGroupSection} />
    </div>
  )
}