import React, {useContext, useEffect, useState} from 'react';
import { Robin } from 'robin.io-js';
import '../../assets/styles/animation.style.css'
import '../../assets/styles/main.style.css'
import { RobinChatContext } from '../../context/RobinChatContext';
import { State } from '../../context/state';
import { API_KEY, CHANNEL, USER_TOKEN } from '../../utils/constants';
import { User } from '../../utils/users-data';
import { MainContent } from '../MainContent/MainContent';
import { Sidebar } from '../Sidebar/Sidebar';

export interface Props {
  apiKey: string,
  userToken: string,
  username: string,
  users: Array<User>,
  keys: Object,
}

export const RobinChat: React.FC<Props> = ({ apiKey, userToken, users, username }) => {

  // INITIALISE ROBIN
  const robin = new Robin(apiKey, true)

  const [state, setState] = useState<State>()
  const [conn, setConn] = useState<WebSocket | undefined>()

  // METHOD TO OPEN ROBIN CONNECTION
  const connect = () => {
    setConn(robin.connect(userToken))
  }

  useEffect(() => {
    connect()
    setAllStateValues()
  }, [])

  // ROBIN CONNECTION CALLBACKS
  if (conn) {
    conn.onopen = async () => {
      robin.subscribe(CHANNEL, conn)
      setAllStateValues()
    }

    conn.onclose = () => {
      connect()
    }

    conn.onerror = (e) => {
      console.error('ERROR', e)
    }

    conn.onmessage = (evt) => {
      // console.log('MESSAGE', JSON.parse(evt.data))
    }
  }

  // SET INITIAL VALUES IN APP-WIDE STATE
  const setAllStateValues = () => {
    const stateLocal: State = {...state}

    stateLocal.users = users.filter(user => user.user_token !== userToken)
    stateLocal.conn = conn
    stateLocal.robin = robin
    stateLocal.username = username
    stateLocal.userToken = userToken
    stateLocal.dialogActive = false
    
    setState(stateLocal)
  }

  function toggleDialogActive(state: State, setState: (state: State) => void) {
    const stateLocal = {...state}
    stateLocal.dialogActive = !stateLocal.dialogActive
    setState(stateLocal)
  }

  return (
    <RobinChatContext.Provider value={{ state, setState }}>
      <div className='robin'>
        <Sidebar />
        <MainContent />
        { state?.dialogActive && <div className="dialog__active_bg" onClick={() => toggleDialogActive(state, setState)}/>}
      </div>
    </RobinChatContext.Provider>
  )
}
