import React, { useContext, useEffect, useState } from 'react';
import { RobinChatContext } from '../../context/RobinChatContext';
import { Conversation } from '../../models/Conversation';
import { ActiveChatList } from '../ActiveChatList/ActiveChatList';
import { ArchivedChatList } from '../ArchivedChatList/ArchivedChatList';
import { ConversationsLoading } from '../ConversationsLoading/ConversationsLoading';
import { EmptyChatList } from '../EmptyChatList/EmptyChatList';
import { NewChat } from '../NewChat/NewChat';
import { NewGroupChat } from '../NewGroupChat/NewGroupChat';
import { SidebarHeader } from '../SidebarHeader/SIdebarHeader';

export const Sidebar: React.FC = () => {
  const {state} = useContext(RobinChatContext)
  const robin = state?.robin
  const userToken = state?.userToken as string
  const [conversations, setConversations] = useState<Array<Conversation> | null>(null)
  const [archivedConversations, setArchivedConversations] = useState<Array<Conversation>>([])

  const getUserToken = async () => {
    const userTokenPromise = await robin?.getUserToken({
      user_token: userToken
    })
    const conversationsData: Array<Conversation> = userTokenPromise?.data.conversations
    setConversations(conversationsData)

    // Get Archived Conversations
    const archived = conversationsData?.filter(conversation => conversation?.archived_for.includes(userToken))
    setArchivedConversations(archived)
  }

  useEffect(() => {
    if (!conversations) {
      getUserToken()
    }
  })

  /**
   * options are active-chat, archive-chat, empty-chat, new-chat
   */
  const [sidebarPartVisible, setSidebarPartVisible] = useState<string>('active-chat')
  return (
    <section className='robin__sidebar'>
      {<SidebarHeader setSidebarPartVisible={setSidebarPartVisible} archivedCount={archivedConversations?.length} />}
      {conversations?.length === 0 && <EmptyChatList />}
      {!conversations && <ConversationsLoading /> }
      {(conversations && conversations?.length > 0) && <ActiveChatList conversations={conversations} />}
      {archivedConversations?.length > 0 && <ArchivedChatList sidebarPartVisible={sidebarPartVisible} setSidebarPartVisible={setSidebarPartVisible} conversations={archivedConversations} />}
      {<NewChat sidebarPartVisible={sidebarPartVisible} setSidebarPartVisible={setSidebarPartVisible} />}
      {<NewGroupChat sidebarPartVisible={sidebarPartVisible} setSidebarPartVisible={setSidebarPartVisible} />}
    </section>
  )
}
