import React, { Dispatch, SetStateAction, useContext } from 'react';
import SvgArchived from '../../icons/Archived';
import SvgMore from '../../icons/More';
import SvgNewChat from '../../icons/NewChat';
import SvgRobinLogo from '../../icons/RobinLogo';
import SvgSearch from '../../icons/Search';
import { SIDEBAR_STATE_ARCHIVE, SIDEBAR_STATE_NEW_CHAT } from '../../utils/constants';

interface Props {
  setSidebarPartVisible: Dispatch<SetStateAction<string>>,
  archivedCount: number
}

export const SidebarHeader: React.FC<Props> = ({ setSidebarPartVisible, archivedCount }) => {

  return (
    <div className="robin__sidebar_header">
      <div className="sidebar__row_1">
        <div className="sidebar__logo">
          <SvgRobinLogo />
        </div>
        <div className="sidebar__actions">
          <button className="sidebar__new_chat icon__btn" onClick={() => setSidebarPartVisible(SIDEBAR_STATE_NEW_CHAT)}>
            <SvgNewChat />
          </button>
          <button className="sidebar__more icon__btn">
            <SvgMore />
          </button>
        </div>
      </div>
      <div className="sidebar__row_2">
        <div className="form__input">
          <input type="text" className='icon__input' placeholder='Search people...' />
          <div className="form__icon">
            <SvgSearch />
          </div>
        </div>
      </div>
      {archivedCount > 0 && <button className="sidebar__archive_btn icon__btn" onClick={() => setSidebarPartVisible(SIDEBAR_STATE_ARCHIVE)}>
        <div className="icon__text">
          <SvgArchived />
          <span className="text">Archived Chats</span>
        </div>
        <span className="archive__count">
          {archivedCount}
        </span>
      </button>}
    </div>
  )
}