import React, { useContext } from "react";
import { RobinChatContext } from "../../context/RobinChatContext";
import { State } from "../../context/state";
import { User } from "../../utils/users-data";
import { Conversation } from "../../models/Conversation";
import { ChatAvatar } from "../ChatAvatar/ChatAvatar";
  
interface Props {
  user: User
}

export const UserCard: React.FC<Props> = ({ user }) => {
  const {state, setState} = useContext(RobinChatContext)
  const robin = state?.robin

  const updateActiveChat = async (activeChat: Conversation) => {
    if (state?.userToken) {
      // Create Conversation before updating as active
      const conversationPromise = await robin?.createConversation({
        sender_name: state?.username || '**Name Missing',
        sender_token: state?.userToken,
        receiver_token: activeChat?.sender_token,
        receiver_name: activeChat?.sender_name
      })
      const conversation: Conversation = conversationPromise.data
      const stateCopy: State = {...state}
      stateCopy.activeChat = conversation
      setState ? setState(stateCopy) : null
    }
  }

  /**
   * This conversation object was created just for the [ChatAvatar] component,
   * It has no fundamental use.
   */
  const dummyConversation: Conversation = {
    _id: 'dummyConversation',
    sender_name: user.fullname,
    sender_token: user.user_token,
    receiver_name: '',
    receiver_token: '',
    created_at: "",
    updated_at: "",
    data: undefined,
    participants: [],
    is_group: false,
    name: "",
    group_icon: "",
    attachments: [],
    moderator: undefined,
    archived_for: "",
    last_message: undefined,
    unread_messages: undefined,
    owner_id: "",
    owner_email: "",
    app_id: "",
    app_name: "",
    deleted_for: null,
    is_deleted: false
  }

  return (
    <div className="robin__chat_card__ctn" onClick={() => updateActiveChat(dummyConversation)}>
      {/* PEOPLE CARD MAIN CONTENT */}
      <div className="robin__chat_card">
        <div className="chat__user_msg icon__text">
          <ChatAvatar conversation={dummyConversation} />
          <div className="user__name_msg text">
            <div className="name">
              { user.fullname }
            </div>
          </div>
        </div>
      </div>
    </div>
  )
}