import { State } from "../context/state"
import { Conversation } from "../models/Conversation"
import TimeAgo from 'javascript-time-ago'
import en from 'javascript-time-ago/locale/en'

TimeAgo.addDefaultLocale(en)

/** */
export const getConversationName = (conversation: Conversation | undefined, state: State | undefined) => {
  if (!conversation?.sender_token && !conversation?.receiver_token) {
    return conversation?.name
  }
  return (conversation?.sender_token === state?.userToken ? conversation?.receiver_name : conversation?.sender_name)
}

/** */
export const getUserInitials = (conversation: Conversation | undefined, state: State | undefined) => {
  const firstName = getConversationName(conversation, state)?.split(' ')[0] || ''
  const lastName = getConversationName(conversation, state)?.split(' ')[1] || ''

  if (conversation?.is_group) return ''

  return `${firstName ? firstName[0] : ''}${lastName ? lastName[0] : ''}`
}

/** */
export const formatTime = (dateString: string | undefined): string => {
  const timeAgo = new TimeAgo('en-us')
  const date = dateString ? new Date(dateString) : new Date(100)
  return !isNaN(date.getTime()) ? timeAgo.format(date.getTime(), 'mini-now').toString() : 'Invalid Date'
}

/** */
export const getConversationLastUpdated = (conversation: Conversation | undefined, state: State | undefined) : string => {
  if (conversation?.last_message) {
    return formatTime(conversation?.last_message?.timestamp)
  }
  return formatTime(conversation?.updated_at)
}

/** */
export const getFilename = (file: string) => {
  const splittedString = file.split('/')
  const secondIndex = splittedString[splittedString.length - 1]
  return secondIndex.replaceAll('%20', ' ')
}

/** */
export const getFileType = (name: string) => {
  if (name !== null) {
    return name.slice(name.length - 4).replace('.', '').trim()
  }
  return 'DOC'
}
